/*
 * Copyright 2003-2006 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.log4j.test; 

import org.apache.log4j.*;
import org.apache.log4j.helpers.LogLog;
import java.io.IOException;

/**
   This class tests the functionality of the Logger class and the
   different layouts.

   @author  Ceki G&uuml;lc&uuml;
*/
public class Min {

  public 
  static 
  void main(String argv[]) {

      if(argv.length == 1) {
	ProgramInit(argv[0]);
      }
      else {
	Usage("Wrong number of arguments.");
      }
      test1();
  }


  static
  void Usage(String msg) {
    System.err.println(msg);
    System.err.println( "Usage: java org.apache.log4j.test.Min format");
    System.exit(1);
  }


  /**
    Program wide initialization method.
    */

  static
  void ProgramInit(String format) {
    try {
      Layout layout = new PatternLayout(format);        
      Appender appender = new FileAppender(layout, System.out);
      Logger.getRoot().addAppender(appender);
    } catch(Exception e) {
      LogLog.error("Could not initialize log4j.");
    }
  }

  
  static
  void test1() {

    int i = 0;

    // In the lines below, the logger names are chosen as an aid in
    // remembering their priority values. In general, the logger
    // names should have no bearing to priority values.
    
    Logger ERR = Logger.getInstance("ERR");
    ERR.setPriority(Priority.ERROR);
    Logger INF = Logger.getInstance("INF");
    INF.setPriority(Priority.INFO);
    Logger INF_ERR = Logger.getInstance("INF.ERR");
    INF_ERR.setPriority(Priority.ERROR);
    Logger DEB = Logger.getInstance("DEB");
    DEB.setPriority(Priority.DEBUG);
    
    // Note: Loggers with undefined priority 
    Logger INF_UNDEF = Logger.getInstance("INF.UNDEF");
    Logger INF_ERR_UNDEF = Logger.getInstance("INF.ERR.UNDEF");    
    Logger UNDEF = Logger.getInstance("UNDEF");   


    // These should all log.----------------------------
    ERR.fatal("Message " + i); i++;  //0
    ERR.error("Message " + i); i++;          
    ERR.info("Message " + i); 
    ERR.debug("Message " + i); 

    INF.fatal("Message " + i); i++; // 2
    INF.error( "Message " + i); i++;         
    INF.warn ( "Message " + i); i++; 
    INF.info ( "Message " + i); i++;

    INF_UNDEF.fatal( "Message " + i); i++;  //6
    INF_UNDEF.error( "Message " + i); i++;         
    INF_UNDEF.warn ( "Message " + i); i++; 
    INF_UNDEF.info ( "Message " + i); i++; 
    INF_UNDEF.debug ( "Message " + i);
    
    
    INF_ERR.fatal( "Message " + i); i++;  // 10
    INF_ERR.error( "Message " + i); i++;  

    INF_ERR_UNDEF.fatal( "Message " + i); i++; 
    INF_ERR_UNDEF.error( "Message " + i); i++;             

    DEB.fatal( "Message " + i); i++;  //14
    DEB.error( "Message " + i); i++;         
    DEB.warn ( "Message " + i); i++; 
    DEB.info ( "Message " + i); i++; 
    DEB.debug( "Message " + i); i++; 

    
    // defaultPriority=DEBUG
    UNDEF.error("Message " + i); i++;         
    UNDEF.warn ("Message " + i); i++; 
    UNDEF.info ("Message " + i); i++; 
    UNDEF.debug("Message " + i, new Exception("Just testing")); i++;    

    // -------------------------------------------------
    // The following should not log
    ERR.warn("Message " + i);  i++; 
    ERR.info("Message " + i);  i++; 
    ERR.debug("Message " + i);  i++; 
      
    INF.debug("Message " + i);  i++; 
    INF_UNDEF.debug("Message " + i); i++; 


    INF_ERR.warn("Message " + i);  i++; 
    INF_ERR.info("Message " + i);  i++; 
    INF_ERR.debug("Message " + i); i++; 
    INF_ERR_UNDEF.warn("Message " + i);  i++; 
    INF_ERR_UNDEF.info("Message " + i);  i++; 
    INF_ERR_UNDEF.debug("Message " + i); i++; 
    // -------------------------------------------------
      
    INF.info("Messages should bear numbers 0 through 22.");
  }     
}
